@@ -1,25 +1,8 @@
 /*
- * Copyright (c) 2020-2023, Stalwart Labs Ltd.
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
  *
- * This file is part of the Stalwart Sieve Interpreter.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- * in the LICENSE file at the top-level directory of this distribution.
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * You can be released from the requirements of the AGPLv3 license by
- * purchasing a commercial license. Please contact licensing@stalw.art
- * for more details.
-*/
+ * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
+ */
 
 use ahash::{AHashMap, AHashSet};
 use serde::{Deserialize, Serialize};
@@ -259,7 +242,7 @@ impl Compiler {
                                 let tag = state.tokens.next().unwrap().unwrap();
                                 let label = state.tokens.expect_static_string()?;
                                 for block in &state.block_stack {
-                                    if block.label.as_ref().map_or(false, |n| n.eq(&label)) {
+                                    if block.label.as_ref().is_some_and(|n| n.eq(&label)) {
                                         return Err(
                                             tag.custom(ErrorType::LabelAlreadyDefined(label))
                                         );
@@ -300,7 +283,7 @@ impl Compiler {
                                 {
                                     if let Word::ForEveryPart = &block.btype {
                                         num_pops += 1;
-                                        if block.label.as_ref().map_or(false, |n| n.eq(&label)) {
+                                        if block.label.as_ref().is_some_and(|n| n.eq(&label)) {
                                             state
                                                 .instructions
                                                 .push(Instruction::ForEveryPartPop(num_pops));
@@ -838,7 +821,7 @@ impl Compiler {
     }
 }
 
-impl<'x> CompilerState<'x> {
+impl CompilerState<'_> {
     pub(crate) fn is_var_local(&self, name: &str) -> bool {
         let name = name.to_ascii_lowercase();
         if self.block.vars_local.contains_key(&name) {
