@@ -1,25 +1,8 @@
 /*
- * Copyright (c) 2020-2023, Stalwart Labs Ltd.
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
  *
- * This file is part of the Stalwart Sieve Interpreter.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- * in the LICENSE file at the top-level directory of this distribution.
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * You can be released from the requirements of the AGPLv3 license by
- * purchasing a commercial license. Please contact licensing@stalw.art
- * for more details.
-*/
+ * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
+ */
 
 use std::{cmp::Ordering, fmt::Display};
 
@@ -29,7 +12,7 @@ use crate::{compiler::Number, runtime::Variable, Context};
 
 use crate::compiler::grammar::expr::{BinaryOperator, Constant, Expression, UnaryOperator};
 
-impl<'x> Context<'x> {
+impl Context<'_> {
     pub(crate) fn eval_expression(&mut self, expr: &[Expression]) -> Result<Variable, Event> {
         let mut exprs = expr.iter().skip(self.expr_pos);
         while let Some(expr) = exprs.next() {
@@ -91,7 +74,7 @@ impl<'x> Context<'x> {
                     }
                 }
                 Expression::JmpIf { val, pos } => {
-                    if self.expr_stack.last().map_or(false, |v| v.to_bool()) == *val {
+                    if self.expr_stack.last().is_some_and(|v| v.to_bool()) == *val {
                         self.expr_pos += *pos as usize;
                         for _ in 0..*pos {
                             exprs.next();
